Documentation
¶
Index ¶
- func GetNonEmptyLines(output string) []string
- func GetProjectDir() (string, error)
- func InstallCertManager() error
- func IsCertManagerCRDsInstalled() bool
- func LoadImageToKindClusterWithName(name string) error
- func Run(cmd *exec.Cmd) (string, error)
- func UncommentCode(filename, target, prefix string) error
- func UninstallCertManager()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetNonEmptyLines ¶
GetNonEmptyLines converts given command output string into individual objects according to line breakers, and ignores the empty elements in it.
func GetProjectDir ¶
GetProjectDir will return the directory where the project is
func InstallCertManager ¶
func InstallCertManager() error
InstallCertManager installs the cert manager bundle. It also patches the cert-manager controller Deployment to set --cluster-resource-namespace=paddock-system so the Phase 2f ClusterIssuer (kind: CA, references the paddock-proxy-ca Secret in paddock-system) can read its source Secret. F-18 / Phase 2f.
func IsCertManagerCRDsInstalled ¶
func IsCertManagerCRDsInstalled() bool
IsCertManagerCRDsInstalled checks if any Cert Manager CRDs are installed by verifying the existence of key CRDs related to Cert Manager.
func LoadImageToKindClusterWithName ¶
LoadImageToKindClusterWithName loads a local docker image to the kind cluster
func UncommentCode ¶
UncommentCode searches for target in the file and remove the comment prefix of the target content. The target content may span multiple lines.
func UninstallCertManager ¶
func UninstallCertManager()
UninstallCertManager uninstalls the cert manager
Types ¶
This section is empty.